@@ -197,9 +197,10 @@ def test_file_autocomplete_root(run_autocomplete: _RunAC) -> None:
 
 @skip_on_windows
 def test_storage_autocomplete(run_autocomplete: _RunAC) -> None:
-    with mock.patch.object(Storage, "stat") as mocked_stat, mock.patch.object(
-        Storage, "list"
-    ) as mocked_list:
+    with (
+        mock.patch.object(Storage, "stat") as mocked_stat,
+        mock.patch.object(Storage, "list") as mocked_list,
+    ):
         tree = {
             URL("storage://default/"): ["test-user", "other-user"],
             URL("storage://default/NO_ORG"): ["test-user", "other-user"],
@@ -316,11 +317,11 @@ def test_storage_autocomplete(run_autocomplete: _RunAC) -> None:
 
 @skip_on_windows
 def test_blob_autocomplete(run_autocomplete: _RunAC) -> None:
-    with mock.patch.object(Buckets, "list") as mocked_list, mock.patch.object(
-        Buckets, "blob_is_dir"
-    ) as mocked_blob_is_dir, mock.patch.object(
-        Buckets, "list_blobs"
-    ) as mocked_list_blobs:
+    with (
+        mock.patch.object(Buckets, "list") as mocked_list,
+        mock.patch.object(Buckets, "blob_is_dir") as mocked_blob_is_dir,
+        mock.patch.object(Buckets, "list_blobs") as mocked_list_blobs,
+    ):
 
         @asyncgeneratorcontextmanager
         async def list(cluster_name: str) -> AsyncIterator[Bucket]:
@@ -615,6 +616,7 @@ def make_job(
         project_name=project_name,
         cluster_name=cluster_name,
         org_name=org_name or "NO_ORG",
+        namespace="",
         id=job_id,
         name=name,
         uri=URL(f"job://{cluster_name}/{owner}/{job_id}"),
@@ -1123,9 +1125,10 @@ def test_nonascii_image_autocomplete(run_autocomplete: _RunAC) -> None:
 
 @skip_on_windows
 def test_image_tag_autocomplete(run_autocomplete: _RunAC) -> None:
-    with mock.patch.object(Images, "list") as mocked_list, mock.patch.object(
-        Images, "tags"
-    ) as mocked_tags:
+    with (
+        mock.patch.object(Images, "list") as mocked_list,
+        mock.patch.object(Images, "tags") as mocked_tags,
+    ):
         image = RemoteImage.new_platform_image(
             name="library/bananas",
             registry="registry-api.dev.apolo.us",
@@ -1573,6 +1576,8 @@ def test_app_autocomplete(run_autocomplete: _RunAC) -> None:
     zsh_out, bash_out = run_autocomplete(["app", ""])
     assert "ls" in bash_out
     assert "ls" in zsh_out
+    assert "install" in bash_out
+    assert "install" in zsh_out
     assert "uninstall" in bash_out
     assert "uninstall" in zsh_out
     assert "get-values" in bash_out
@@ -1587,3 +1592,5 @@ def test_app_template_autocomplete(run_autocomplete: _RunAC) -> None:
     zsh_out, bash_out = run_autocomplete(["app-template", ""])
     assert "ls" in bash_out
     assert "ls" in zsh_out
+    assert "get" in bash_out
+    assert "get" in zsh_out
