@@ -33,12 +33,9 @@ def _job_entry(
     cluster_name: str = "default",
     owner: str = "user",
     project_name: str = "project",
-    org_name: Optional[str] = None,
+    org_name: str = "NO_ORG",
 ) -> Dict[str, Any]:
-    if org_name:
-        uri = f"job://{cluster_name}/{org_name}/{project_name}/{job_id}"
-    else:
-        uri = f"job://{cluster_name}/{project_name}/{job_id}"
+    uri = f"job://{cluster_name}/{org_name}/{project_name}/{job_id}"
     return {
         "id": job_id,
         "owner": owner,
@@ -61,7 +58,7 @@ def _job_entry(
             "command": "sleep 1h",
             "resources": {"cpu": 0.1, "memory": 2**30, "shm": True},
         },
-        "ssh_auth_server": "ssh://nobody@ssh-auth-dev.neu.ro:22",
+        "ssh_auth_server": "ssh://nobody@ssh-auth-api.dev.apolo.us:22",
         "scheduler_enabled": True,
         "pass_config": False,
         "name": "my-job-name",
@@ -149,6 +146,8 @@ async def test_resolve_job_id__from_uri_with_same_project__no_jobs_found(
         )
         assert resolved_ex == (job_name, cluster_name)
 
+    await srv.close()
+
 
 async def test_resolve_job_id__from_uri_with_other_project__no_jobs_found(
     aiohttp_server: _TestServerFactory, make_client: _MakeClient
@@ -179,6 +178,8 @@ async def test_resolve_job_id__from_uri_with_other_project__no_jobs_found(
         with pytest.raises(ValueError):
             await resolve_job_ex(uri, client=client, status={JobStatus.RUNNING})
 
+    await srv.close()
+
 
 async def test_resolve_job_id__from_uri_without_project__no_jobs_found(
     aiohttp_server: _TestServerFactory, make_client: _MakeClient
@@ -210,18 +211,23 @@ async def test_resolve_job_id__from_uri_without_project__no_jobs_found(
         )
         assert resolved_ex == (job_name, "default")
 
+    await srv.close()
+
 
 async def test_resolve_job_id__from_string__single_job_found(
     aiohttp_server: _TestServerFactory, make_client: _MakeClient
 ) -> None:
     job_name = "test-job-name-555"
     job_id = "job-id-1"
-    JSON = {"jobs": [_job_entry(job_id, project_name="test-project")]}
+    JSON = {
+        "jobs": [_job_entry(job_id, project_name="test-project", org_name="NO_ORG")]
+    }
 
     async def handler(request: web.Request) -> web.Response:
         _check_params(
             request,
             name=job_name,
+            org_name="NO_ORG",
             project_name="test-project",
             cluster_name="default",
             reverse="1",
@@ -243,14 +249,16 @@ async def test_resolve_job_id__from_string__single_job_found(
         )
         assert resolved_ex == (job_id, "default")
 
+    await srv.close()
+
 
 @pytest.mark.parametrize("cluster_name", ["default", "other"])
-@pytest.mark.parametrize("org_name", [None, "test-org"])
+@pytest.mark.parametrize("org_name", ["NO_ORG", "test-org"])
 async def test_resolve_job_id__from_uri_with_same_project__single_job_found(
     aiohttp_server: _TestServerFactory,
     make_client: _MakeClient,
     cluster_name: str,
-    org_name: Optional[str],
+    org_name: str,
 ) -> None:
     job_project = "test-project"
     job_name = "my-job-name"
@@ -258,7 +266,12 @@ async def test_resolve_job_id__from_uri_with_same_project__single_job_found(
     job_id = "job-id-1"
     JSON = {
         "jobs": [
-            _job_entry(job_id, cluster_name=cluster_name, project_name=job_project)
+            _job_entry(
+                job_id,
+                cluster_name=cluster_name,
+                project_name=job_project,
+                org_name=org_name,
+            )
         ]
     }
 
@@ -269,6 +282,7 @@ async def test_resolve_job_id__from_uri_with_same_project__single_job_found(
             project_name=job_project,
             cluster_name=cluster_name,
             reverse="1",
+            org_name=org_name,
         )
         return web.json_response(JSON)
 
@@ -285,6 +299,8 @@ async def test_resolve_job_id__from_uri_with_same_project__single_job_found(
         )
         assert resolved_ex == (job_id, cluster_name)
 
+    await srv.close()
+
 
 @pytest.mark.parametrize("cluster_name", ["default", "other"])
 @pytest.mark.parametrize("org_name", [None, "test-org", "job-org"])
@@ -338,14 +354,16 @@ async def test_resolve_job_id__from_uri_with_org__single_job_found(
         )
         assert resolved_ex == (job_id, cluster_name)
 
+    await srv.close()
+
 
 @pytest.mark.parametrize("cluster_name", ["default", "other"])
-@pytest.mark.parametrize("org_name", [None, "test-org"])
+@pytest.mark.parametrize("org_name", ["NO_ORG", "test-org"])
 async def test_resolve_job_id__from_uri__multiple_jobs_found(
     aiohttp_server: _TestServerFactory,
     make_client: _MakeClient,
     cluster_name: str,
-    org_name: Optional[str],
+    org_name: str,
 ) -> None:
     job_org = "job-org"
     job_project = "test-project"
@@ -366,7 +384,12 @@ async def test_resolve_job_id__from_uri__multiple_jobs_found(
                 project_name=job_project,
                 org_name=job_org,
             ),
-            _job_entry(job_ids[2], cluster_name=cluster_name, project_name=job_project),
+            _job_entry(
+                job_ids[2],
+                cluster_name=cluster_name,
+                project_name=job_project,
+                org_name=org_name,
+            ),
             _job_entry(
                 job_ids[3],
                 cluster_name=cluster_name,
@@ -383,6 +406,7 @@ async def test_resolve_job_id__from_uri__multiple_jobs_found(
             project_name=job_project,
             cluster_name=cluster_name,
             reverse="1",
+            org_name=org_name,
         )
         return web.json_response(JSON)
 
@@ -399,14 +423,16 @@ async def test_resolve_job_id__from_uri__multiple_jobs_found(
         )
         assert resolved_ex == (job_ids[2], cluster_name)
 
+    await srv.close()
+
 
 @pytest.mark.parametrize("cluster_name", ["default", "other"])
-@pytest.mark.parametrize("org_name", [None, "test-org"])
+@pytest.mark.parametrize("org_name", ["NO_ORG", "test-org"])
 async def test_resolve_job_id__from_uri_with_org__multiple_jobs_found(
     aiohttp_server: _TestServerFactory,
     make_client: _MakeClient,
     cluster_name: str,
-    org_name: Optional[str],
+    org_name: str,
 ) -> None:
     job_org = "job-org"
     job_project = "test-project"
@@ -444,6 +470,7 @@ async def test_resolve_job_id__from_uri_with_org__multiple_jobs_found(
             project_name=[f"{job_org}/{job_project}", job_project],
             cluster_name=cluster_name,
             reverse="1",
+            org_name=org_name,
         )
         return web.json_response(JSON)
 
@@ -460,12 +487,14 @@ async def test_resolve_job_id__from_uri_with_org__multiple_jobs_found(
         )
         assert resolved_ex == (job_ids[2], cluster_name)
 
+    await srv.close()
 
-@pytest.mark.parametrize("org_name", [None, "test-org"])
+
+@pytest.mark.parametrize("org_name", ["NO_ORG", "test-org"])
 async def test_resolve_job_id__from_uri_without_project__single_job_found(
     aiohttp_server: _TestServerFactory,
     make_client: _MakeClient,
-    org_name: Optional[str],
+    org_name: str,
 ) -> None:
     job_name = "my-job-name"
     uri = f"job:{job_name}"
@@ -497,6 +526,8 @@ async def test_resolve_job_id__from_uri_without_project__single_job_found(
         )
         assert resolved_ex == (job_id, "default")
 
+    await srv.close()
+
 
 async def test_resolve_job_id__server_error(
     aiohttp_server: _TestServerFactory, make_client: _MakeClient
@@ -529,6 +560,8 @@ async def test_resolve_job_id__server_error(
         )
         assert resolved_ex == (job_id, "default")
 
+    await srv.close()
+
 
 @pytest.mark.parametrize("cluster_name", ["default", "other"])
 async def test_resolve_job_id__from_uri_with_same_project__server_error(
@@ -561,6 +594,8 @@ async def test_resolve_job_id__from_uri_with_same_project__server_error(
         )
         assert resolved_ex == (job_name, cluster_name)
 
+    await srv.close()
+
 
 async def test_resolve_job_id__from_uri_with_other_project__server_error(
     aiohttp_server: _TestServerFactory, make_client: _MakeClient
@@ -590,6 +625,8 @@ async def test_resolve_job_id__from_uri_with_other_project__server_error(
         with pytest.raises(ValueError):
             await resolve_job_ex(uri, client=client, status={JobStatus.RUNNING})
 
+    await srv.close()
+
 
 async def test_resolve_job_id__from_uri_without_project__server_error(
     aiohttp_server: _TestServerFactory, make_client: _MakeClient
@@ -620,22 +657,24 @@ async def test_resolve_job_id__from_uri_without_project__server_error(
         )
         assert resolved_ex == (job_name, "default")
 
+    await srv.close()
+
 
 @pytest.mark.parametrize(
     "uri",
     [
-        "job:",
+        # "job:",
         "job:/",
-        "job://",
+        # "job://",
         "job:///",
         "job://default",
         "job://default/",
-        "job://default/user",
-        "job://default/user/",
-        "job://default/user/name/",
+        # "job://default/user",
+        # "job://default/user/",
+        # "job://default/user/name/",
         "job://default/org/user/name/",
-        "job:/user",
-        "job:/user/",
+        # "job:/user",
+        # "job:/user/",
         "job:/user/name/",
         "job:name/",
     ],
@@ -656,8 +695,8 @@ async def test_resolve_job_id__from_uri__invalid(
 def test_parse_file_resource_no_scheme(root: Root) -> None:
     parsed = parse_file_resource("scheme-less/resource", root)
     assert parsed == URL((Path.cwd() / "scheme-less/resource").as_uri())
-    parsed = parse_file_resource("c:scheme-less/resource", root)
-    assert parsed == URL((Path("c:scheme-less").resolve() / "resource").as_uri())
+    parsed = parse_file_resource("C:scheme-less/resource", root)
+    assert parsed == URL((Path("C:scheme-less").resolve() / "resource").as_uri())
 
 
 def test_parse_file_resource_unsupported_scheme(root: Root) -> None:
@@ -671,7 +710,7 @@ def test_parse_file_resource_project_less(root: Root) -> None:
     user_less_permission = parse_file_resource("storage:resource", root)
     assert user_less_permission == URL(
         f"storage://{root.client.cluster_name}"
-        f"/{root.client.config.project_name}/resource"
+        f"/NO_ORG/{root.client.config.project_name}/resource"
     )
 
 
@@ -699,7 +738,7 @@ def test_parse_resource_for_sharing_image_no_tag(root: Root) -> None:
     parsed = parse_resource_for_sharing(uri, root)
     assert parsed == URL(
         f"image://{root.client.cluster_name}"
-        f"/{root.client.config.project_name}/ubuntu"
+        f"/NO_ORG/{root.client.config.project_name}/ubuntu"
     )
 
 
@@ -708,9 +747,9 @@ def test_parse_resource_for_sharing_image_non_ascii(root: Root) -> None:
     parsed = parse_resource_for_sharing(uri, root)
     assert parsed == URL(
         f"image://{root.client.cluster_name}"
-        f"/{root.client.config.project_name}/образ"
+        f"/NO_ORG/{root.client.config.project_name}/образ"
     )
-    assert parsed.path == f"/{root.client.config.project_name}/образ"
+    assert parsed.path == f"/NO_ORG/{root.client.config.project_name}/образ"
 
 
 def test_parse_resource_for_sharing_image_percent_encoded(root: Root) -> None:
@@ -718,9 +757,9 @@ def test_parse_resource_for_sharing_image_percent_encoded(root: Root) -> None:
     parsed = parse_resource_for_sharing(uri, root)
     assert parsed == URL(
         f"image://{root.client.cluster_name}"
-        f"/{root.client.config.project_name}/%252d%3f%23"
+        f"/NO_ORG/{root.client.config.project_name}/%252d%3f%23"
     )
-    assert parsed.path == f"/{root.client.config.project_name}/%2d?#"
+    assert parsed.path == f"/NO_ORG/{root.client.config.project_name}/%2d?#"
 
 
 def test_parse_resource_for_sharing_image_with_tag_fail(root: Root) -> None:
@@ -732,7 +771,7 @@ def test_parse_resource_for_sharing_image_with_tag_fail(root: Root) -> None:
 def test_parse_resource_for_sharing_all_project_images(root: Root) -> None:
     uri = "image:/otherproject"
     parsed = parse_resource_for_sharing(uri, root)
-    assert parsed == URL(f"image://{root.client.cluster_name}/otherproject")
+    assert parsed == URL(f"image://{root.client.cluster_name}/NO_ORG/otherproject")
 
 
 def _test_parse_resource_for_sharing_all_cluster_images(root: Root) -> None:
@@ -759,7 +798,7 @@ def test_parse_resource_for_sharing_user_less(root: Root) -> None:
     user_less_permission = parse_resource_for_sharing("storage:resource", root)
     assert user_less_permission == URL(
         f"storage://{root.client.cluster_name}"
-        f"/{root.client.config.project_name}/resource"
+        f"/NO_ORG/{root.client.config.project_name}/resource"
     )
 
 
@@ -904,7 +943,7 @@ async def test_calc_life_span_none_default(
         "https://example.com", plugin_manager=plugin_manager
     ) as client:
         monkeypatch.chdir(tmp_path)
-        local_conf = tmp_path / ".neuro.toml"
+        local_conf = tmp_path / ".apolo.toml"
         local_conf.write_text(toml.dumps({"job": {"life-span": "1d2h3m4s"}}))
         expected = timedelta(days=1, hours=2, minutes=3, seconds=4)
         assert (
@@ -922,7 +961,7 @@ async def test_calc_life_span_default_life_span_all_keys(
         "https://example.com", plugin_manager=plugin_manager
     ) as client:
         monkeypatch.chdir(tmp_path)
-        local_conf = tmp_path / ".neuro.toml"
+        local_conf = tmp_path / ".apolo.toml"
         # empty config
         local_conf.write_text(toml.dumps({"job": {"life-span": "1d2h3m4s"}}))
 
@@ -945,7 +984,7 @@ async def test_calc_default_life_span_invalid(
         "https://example.com", plugin_manager=plugin_manager
     ) as client:
         monkeypatch.chdir(tmp_path)
-        local_conf = tmp_path / ".neuro.toml"
+        local_conf = tmp_path / ".apolo.toml"
         # empty config
         local_conf.write_text(toml.dumps({"job": {"life-span": "invalid"}}))
         with pytest.raises(
@@ -963,7 +1002,7 @@ async def test_calc_default_life_span_default_value(
 ) -> None:
     async with make_client("https://example.com") as client:
         monkeypatch.chdir(tmp_path)
-        local_conf = tmp_path / ".neuro.toml"
+        local_conf = tmp_path / ".apolo.toml"
         # empty config
         local_conf.write_text(toml.dumps(cast(Dict[str, Any], {})))
         default = parse_timedelta("1d")
